Subject: [bug#70855] [PATCH 26/92] gnu: python-arrow: Move to pyproject-build-system.

From: Nicolas Graves <[email-masked]>
Date: Fri, 10 May 2024 00:53:21 +0200

* gnu/packages/time.scm (python-arrow): Improve package style.
  [build-system]: Move to pyproject-build-system.
  [arguments]: Moving check replacement phase from <#:phases> to
  equivalent <#:test-flags>.

Change-Id: I7e3d356610d624855c3898ccdbfb308ce9f6e627
---
 gnu/packages/time.scm | 16 ++++++----------
 1 file changed, 6 insertions(+), 10 deletions(-)

diff --git a/gnu/packages/time.scm b/gnu/packages/time.scm
index 5e20f05fb6c..96fe9f561a0 100644
--- a/gnu/packages/time.scm
+++ b/gnu/packages/time.scm
@@ -507,17 +507,13 @@ (define-public python-arrow
               (sha256
                (base32
                 "189knrgxb3x21lzvqac6qlpd32308hcmpccxdlvr5wmrl46b6d1r"))))
-    (build-system python-build-system)
+    (build-system pyproject-build-system)
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (replace 'check
-           (lambda* (#:key tests? #:allow-other-keys)
-             (when tests?
-               (invoke "pytest" "-vv" "tests"
-                       ;; python-dateutil doesn't recognize America/Nuuk.
-                       ;; Remove when python-dateutil > 2.8.1.
-                       "-k" "not test_parse_tz_name_zzz")))))))
+     (list
+      #:test-flags '(list "tests"
+                          ;; python-dateutil doesn't recognize America/Nuuk.
+                          ;; Remove when python-dateutil > 2.8.1.
+                          "-k" "not test_parse_tz_name_zzz")))
     (native-inputs
      (list ;; For testing
            python-chai
-- 
2.41.0